.. image:: https://api.travis-ci.org/bsvetchine/django-payzen.svg?branch=master
    :target: https://travis-ci.org/bsvetchine/django-payzen
    :alt: Travis CI Status

django-payzen
=============

Django app for payzen Electronic Payment Terminal.

Read extended documentation provided at `Read the Docs <http://django-payzen.readthedocs.org/en/latest/>`_ .
